@@ -125,9 +125,22 @@ bool TubeApi::processRoutingApiResult( QIODevice *source )
 {
 	d->results.clear();
 
-	d->results << source->readAll();
+	QTextStream stream(source);
 
-	//qDebug() << "Results" << d->results;
+	bool start = false, end = false;
+	while ( !stream.atEnd() )
+	{
+		QString line = stream.readLine();
+
+		if ( start && end ) break;
+
+		if ( start ) d->results << line;
+		else if ( line.contains("<h1 class=\"route\">") ) start = true;
+
+		if ( line.contains("</table>") ) end = true;
+	}
+
+	//qDebug() << d->results;
 
 	return true;
 }
